%bcond_with     texlive

Summary:        A unit test framework for C
Name:           check
Version:        0.15.2
Release:        7%{?dist}
Source0:        https://github.com/libcheck/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
License:        LGPLv2+
URL:            http://libcheck.github.io/check/
Patch3001:      %{name}-0.11.0-info-in-builddir.patch
Patch3002:      %{name}-0.11.0-fp.patch

BuildRequires:  cmake, gcc, make, libtool, patchutils, pkgconfig
BuildRequires:  pkgconfig(libsubunit) graphviz
%if %{with texlive}
BuildRequires:  texinfo, texlive-tex
%endif

%description
Check is a unit test framework for C. It features a simple interface for 
defining unit tests, putting little in the way of the developer. Tests 
are run in a separate address space, so Check can catch both assertion 
failures and code errors that cause segmentation faults or other signals. 
The output from unit tests can be used within source code editors and IDEs.

%package devel
Summary:        Libraries and headers for developing programs with check
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
Libraries and headers for developing programs with check

%package static
Summary:        Static libraries of check

%description static
Static libraries of check.

%package checkmk
Summary:        Translate concise versions of test suites into C programs
License:        BSD
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description checkmk
The checkmk binary translates concise versions of test suites into C
programs suitable for use with the Check unit test framework.



%prep
%autosetup -p1

sed -e '/DECLS(\[a/s|)|,,,[AC_INCLUDES_DEFAULT\n[#include <time.h>\n #include <sys/time.h>]]&|' \
    -i configure.ac

find . -name .cvsignore -delete

autoreconf -ivf

sed -i 's,set(libdir .*),set(libdir "%{_libdir}"),' CMakeLists.txt



%build
mkdir autotools_build
cd autotools_build
%global _configure ../configure
%configure \
    --disable-timeout-tests \
%if %{without texlive}
    --disable-build_docs \
%endif
    %{nil}

sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|CC="\(.*g..\)"|CC="\1 -Wl,--as-needed"|' \
    -i libtool

%make_build
cd -

%cmake -DCHECK_ENABLE_TIMEOUT_TESTS:BOOL=OFF .
%cmake_build



%install
cd autotools_build
%make_install
rm -rf %{buildroot}%{_libdir}
rm -rf %{buildroot}%{_infodir}/dir
rm -rf %{buildroot}%{_docdir}/%{name}
cd -

%cmake_install

sed -i 's/ -pthread//' %{buildroot}%{_libdir}/pkgconfig/check.pc

%check
cd autotools_build
export LD_LIBRARY_PATH=$PWD/src/.libs
make check
rm -rf checkmk/test/check_checkmk*
rm -rf checkmk/test/empty_input
cd -



%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig



%files
%doc AUTHORS NEWS
%license COPYING.LESSER
%{_libdir}/libcheck.so.0*
%if %{with texlive}
%{_infodir}/check*
%endif

%files devel
%doc doc/example
%{_includedir}/check.h
%{_includedir}/check_stdint.h
%{_libdir}/cmake/check/
%{_libdir}/libcheck.so
%{_libdir}/pkgconfig/check.pc
%{_datadir}/aclocal/check.m4

%files static
%license COPYING.LESSER
%{_libdir}/libcheck.a

%files checkmk
%doc checkmk/README checkmk/examples
%doc checkmk/test
%{_bindir}/checkmk
%{_mandir}/man1/checkmk.1*



%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.15.2-7
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.15.2-6
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.15.2-5
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.15.2-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.15.2-3
- Rebuilt for OpenCloudOS Stream 23

* Mon Feb 20 2023 Shuo Wang <abushwang@tencent.com> - 0.15.2-2
- remove unused buildrequires

* Wed Nov 16 2022 Zhao Zhen <jeremiazhao@tencent.com> - 0.15.2-1
- initial
